data.frameCalls JIRA's latest REST API, optionally with basic authentication, to get all issues of a JIRA query (JQL). Allows to specify which fields to obtain.
get_jira_issues(
domain = NULL,
username = NULL,
password = NULL,
jql_query,
fields = basic_jql_fields(),
maxResults = 50,
verbose = FALSE,
as.data.frame = TRUE
)Custom JIRA domain URL as for example
https://bugreports.qt.io. Can be passed as a
parameter or can be previously defined through the save_jira_credentials() function.
Username used to authenticate the access to the JIRA domain.
If both username and password are not passed no authentication is made and only
public domains can bet accessed. Optional parameter.
Password used to authenticate the access to the JIRA domain.
If both username and password are not passed no authentication is made and only
public domains can bet accessed. Optional parameter.
JIRA's decoded JQL query. By definition, it works with:
Fields
Operators
Keywords
Functions
To learn how to create a query visit this ATLASSIAN site or the following cheatsheet.
Optional argument to define the specific JIRA fields to obtain. If no value is entered, by default the following fields are passed:
status
priority
created
reporter
summary
description
assignee
updated
issuetype
fixVersions
To obtain a list of all supported fields use the following function: supported_jql_fields().
Max results authorized to obtain for each API call. By default JIRA sets this value to 50 issues.
Explicitly informs the user of the JIRA API request process.
Defines if the function returns a flattened data.frame or the raw JIRA response.
Returns a flattened, formatted data.frame with the issues according to the JQL query.
If the comment field is used as a fields parameter input, each issue and its
attributes are repeated the number of comments the issue has. The function works with the
latest JIRA REST API and to work you need to have a internet connection. Calling the function
too many times might block your access, you will receive a 403 error code. To unblock your
access you will have to access interactively through your browser, signing out and signing
in again, and might even have to enter a CAPTCHA at
https://jira.yourdomain.com/secure/Dashboard.jspa. This only happens if the API
is called upon multiple times in a short period of time.
For more information about Atlassians JIRA API visit the following link: JIRA API Documentation.
# NOT RUN {
get_jira_issues(domain = "https://bugreports.qt.io",
jql_query = 'project="QTWB"')
# }
Run the code above in your browser using DataLab