Learn R Programming

JirAgileR (version 0.0.2.1)

supported_jql_fields: Returns the supported JQL fields

Description

Function shows all the supported JQL fields that are available to choose for the get_jira_issues() function.

Usage

supported_jql_fields()

Arguments

Value

Returns a character vector of all the supported JQL fields.