get_jira_dashboards: Retrieves all dashboards a data.frame
Description
Calls JIRA's latest REST API, optionally with
basic authentication, to get all dashboards
Usage
get_jira_dashboards(
domain = NULL,
username = NULL,
password = NULL,
maxResults = 20L,
verbose = FALSE
)
Arguments
domain
Custom JIRA domain URL as for example
https://bugreports.qt.io. Can be passed as a parameter
or can be previously defined through the save_jira_credentials() function.
username
Username used to authenticate the access to the JIRA domain.
If both username and password are not passed no authentication is made and only
public domains can bet accessed. Optional parameter.
password
Password used to authenticate the access to the JIRA domain.
If both username and password are not passed no authentication is made and only
public domains can bet accessed. Optional parameter.
maxResults
Max results authorized to obtain for each API call. By default
JIRA sets this value to 20 issues.
verbose
Explicitly informs the user of the JIRA API request process.
Value
Returns a flattened, formatted data.frame with the dashboards in the domain.
Examples
Run this code# NOT RUN {
get_jira_dashboards(domain = "https://bugreports.qt.io")
# }
Run the code above in your browser using DataLab