data.frameMakes a request to JIRA's latest REST API to retrieve all the groups in JIRA.
get_jira_groups(
domain = NULL,
username = NULL,
password = NULL,
verbose = FALSE,
maxResults = 1000
)Custom JIRA domain URL as for example
https://bugreports.qt.io. Can be passed
as a parameter or can be previously defined through the save_jira_credentials() function.
Username used to authenticate the access to the JIRA domain.
If both username and password are not passed no authentication is made and only
public domains can bet accessed. Optional parameter.
Password used to authenticate the access to the JIRA domain.
If both username and password are not passed no authentication is made and only
public domains can bet accessed. Optional parameter.
Explicitly informs the user of the JIRA API request process.
Number of maximum groups to return. Set by default to 1000.
Returns a data.frame with all the JIRA groups
The function works with the latest JIRA REST API and to work you need to have a internet connection. Calling the function too many times might block your access, you will receive a 403 error code. To unblock your access you will have to access interactively through your browser, signing out and signing in again, and might even have to enter a CAPTCHA at https://jira.yourdomain.com/secure/Dashboard.jspa. This only happens if the API is called upon multiple times in a short period of time.
For more information about Atlassians JIRA API go to JIRA API Documentation
# NOT RUN {
get_jira_groups("https://bugreports.qt.io")
# }
Run the code above in your browser using DataLab