powered by
Function shows all the supported JQL fields that are available to choose for the get_jira_issues() function.
get_jira_issues()
supported_jql_fields()
Returns a character vector of all the supported JQL fields.